gatein SVN: r1824 - in portal/trunk: component/common/src/main/java/org/exoplatform/commons and 11 other directories.
by do-not-reply@jboss.org
Author: julien_viet
Date: 2010-02-23 11:55:05 -0500 (Tue, 23 Feb 2010)
New Revision: 1824
Added:
portal/trunk/component/common/src/main/java/org/exoplatform/commons/xml/
portal/trunk/component/common/src/main/java/org/exoplatform/commons/xml/DocumentSource.java
portal/trunk/component/common/src/main/java/org/exoplatform/commons/xml/ResourceEntityResolver.java
portal/trunk/component/common/src/main/java/org/exoplatform/commons/xml/ValidationReporter.java
portal/trunk/component/common/src/main/java/org/exoplatform/commons/xml/XMLValidator.java
portal/trunk/component/portal/src/main/java/gatein_resources_1_0.xsd
Removed:
portal/trunk/component/portal/src/main/java/gatein_resources_1_0.xsd
Modified:
portal/trunk/component/portal/src/main/java/org/exoplatform/portal/resource/GateInSkinConfigDeployer.java
portal/trunk/component/portal/src/main/java/org/exoplatform/portal/resource/config/xml/SkinConfigParser.java
portal/trunk/examples/extension/war/src/main/webapp/WEB-INF/gatein-resources.xml
portal/trunk/examples/portal/war/src/main/webapp/WEB-INF/gatein-resources.xml
portal/trunk/pom.xml
portal/trunk/portlet/dashboard/src/main/webapp/WEB-INF/gatein-resources.xml
portal/trunk/portlet/exoadmin/src/main/webapp/WEB-INF/gatein-resources.xml
portal/trunk/portlet/web/src/main/webapp/WEB-INF/gatein-resources.xml
portal/trunk/web/eXoResources/src/main/webapp/WEB-INF/gatein-resources.xml
portal/trunk/web/portal/src/main/webapp/WEB-INF/gatein-resources.xml
Log:
GTNPORTAL-735 : Validates gatein-resources files using the 1.0 Schema
Added: portal/trunk/component/common/src/main/java/org/exoplatform/commons/xml/DocumentSource.java
===================================================================
--- portal/trunk/component/common/src/main/java/org/exoplatform/commons/xml/DocumentSource.java (rev 0)
+++ portal/trunk/component/common/src/main/java/org/exoplatform/commons/xml/DocumentSource.java 2010-02-23 16:55:05 UTC (rev 1824)
@@ -0,0 +1,76 @@
+/*
+ * Copyright (C) 2009 eXo Platform SAS.
+ *
+ * This is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2.1 of
+ * the License, or (at your option) any later version.
+ *
+ * This software is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this software; if not, write to the Free
+ * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ */
+
+package org.exoplatform.commons.xml;
+
+import java.io.IOException;
+import java.io.InputStream;
+import java.net.URL;
+
+/**
+ * @author <a href="mailto:julien.viet@exoplatform.com">Julien Viet</a>
+ * @version $Revision$
+ */
+public abstract class DocumentSource
+{
+
+ /** Some kind of identifier for error reporting. */
+ private String identifier;
+
+ private DocumentSource(String identifier)
+ {
+ if (identifier == null)
+ {
+ throw new NullPointerException("An identifier must be provided");
+ }
+ this.identifier = identifier;
+ }
+
+ public String getIdentifier()
+ {
+ return identifier;
+ }
+
+ public abstract InputStream getStream() throws IOException;
+
+ public static DocumentSource create(String identifier, final InputStream in)
+ {
+ return new DocumentSource(identifier)
+ {
+ @Override
+ public InputStream getStream() throws IOException
+ {
+ return in;
+ }
+ };
+ }
+
+ public static DocumentSource create(final URL url)
+ {
+ return new DocumentSource(url.toString())
+ {
+ @Override
+ public InputStream getStream() throws IOException
+ {
+ return url.openStream();
+ }
+ };
+ }
+
+}
Added: portal/trunk/component/common/src/main/java/org/exoplatform/commons/xml/ResourceEntityResolver.java
===================================================================
--- portal/trunk/component/common/src/main/java/org/exoplatform/commons/xml/ResourceEntityResolver.java (rev 0)
+++ portal/trunk/component/common/src/main/java/org/exoplatform/commons/xml/ResourceEntityResolver.java 2010-02-23 16:55:05 UTC (rev 1824)
@@ -0,0 +1,129 @@
+/*
+ * Copyright (C) 2009 eXo Platform SAS.
+ *
+ * This is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2.1 of
+ * the License, or (at your option) any later version.
+ *
+ * This software is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this software; if not, write to the Free
+ * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ */
+
+package org.exoplatform.commons.xml;
+
+import org.exoplatform.commons.utils.IOUtil;
+import org.xml.sax.EntityResolver;
+import org.xml.sax.InputSource;
+import org.xml.sax.SAXException;
+
+import java.io.ByteArrayInputStream;
+import java.io.IOException;
+import java.io.InputStream;
+import java.util.Collections;
+import java.util.HashMap;
+import java.util.Map;
+import java.util.concurrent.ConcurrentHashMap;
+import java.util.concurrent.ConcurrentMap;
+
+/**
+ * @author <a href="mailto:julien.viet@exoplatform.com">Julien Viet</a>
+ * @version $Revision$
+ */
+public class ResourceEntityResolver implements EntityResolver
+{
+
+ /** . */
+ private final Map<String, String> systemIdToResourcePath;
+
+ /** . */
+ private final ConcurrentMap<String, byte[]> systemIdToSource;
+
+ /** . */
+ private final ClassLoader loader;
+
+ public ResourceEntityResolver(Class clazz, String systemId, String resourcePath)
+ {
+ this(clazz.getClassLoader(), Collections.singletonMap(systemId, resourcePath));
+ }
+
+ public ResourceEntityResolver(ClassLoader loader, String systemId, String resourcePath)
+ {
+ this(loader, Collections.singletonMap(systemId, resourcePath));
+ }
+
+ public ResourceEntityResolver(Class clazz, Map<String, String> systemIdToResourcePath)
+ {
+ this(clazz.getClassLoader(), systemIdToResourcePath);
+ }
+
+ public ResourceEntityResolver(ClassLoader loader, Map<String, String> systemIdToResourcePath)
+ {
+ if (loader == null)
+ {
+ throw new NullPointerException();
+ }
+ if (systemIdToResourcePath == null)
+ {
+ throw new NullPointerException();
+ }
+
+ // Defensive copy
+ this.systemIdToResourcePath = new HashMap<String, String>(systemIdToResourcePath);
+ this.systemIdToSource = new ConcurrentHashMap<String, byte[]>();
+ this.loader = loader;
+ }
+
+ public InputSource resolveEntity(String publicId, String systemId) throws SAXException, IOException
+ {
+ if (systemId != null)
+ {
+ byte[] data = systemIdToSource.get(systemId);
+
+ //
+ if (data == null)
+ {
+ String path = systemIdToResourcePath.get(systemId);
+ if (path != null)
+ {
+ InputStream in = loader.getResourceAsStream(path);
+ if (in != null)
+ {
+ data = IOUtil.getStreamContentAsBytes(in);
+ }
+ }
+
+ // Black list it, we won't find it
+ if (data == null)
+ {
+ data = new byte[0];
+ }
+
+ // Put in cache
+ systemIdToSource.put(systemId, data);
+
+ // Some basic prevention against stupid use of this class that could cause OOME
+ if (systemIdToSource.size() > 1000)
+ {
+ systemIdToSource.clear();
+ }
+ }
+
+ //
+ if (data != null && data.length > 0)
+ {
+ return new InputSource(new ByteArrayInputStream(data));
+ }
+ }
+
+ //
+ return null;
+ }
+}
Added: portal/trunk/component/common/src/main/java/org/exoplatform/commons/xml/ValidationReporter.java
===================================================================
--- portal/trunk/component/common/src/main/java/org/exoplatform/commons/xml/ValidationReporter.java (rev 0)
+++ portal/trunk/component/common/src/main/java/org/exoplatform/commons/xml/ValidationReporter.java 2010-02-23 16:55:05 UTC (rev 1824)
@@ -0,0 +1,73 @@
+/*
+ * Copyright (C) 2009 eXo Platform SAS.
+ *
+ * This is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2.1 of
+ * the License, or (at your option) any later version.
+ *
+ * This software is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this software; if not, write to the Free
+ * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ */
+
+package org.exoplatform.commons.xml;
+
+import org.gatein.common.logging.Logger;
+import org.xml.sax.ErrorHandler;
+import org.xml.sax.SAXException;
+import org.xml.sax.SAXParseException;
+
+/**
+ * @author <a href="mailto:julien.viet@exoplatform.com">Julien Viet</a>
+ * @version $Revision$
+ */
+public class ValidationReporter implements ErrorHandler
+{
+
+ /** . */
+ private final String identifier;
+
+ /** . */
+ private boolean valid;
+
+ /** . */
+ private Logger log;
+
+ public ValidationReporter(Logger log, String identifier)
+ {
+ this.identifier = identifier;
+ this.log = log;
+ this.valid = true;
+ }
+
+ public boolean isValid()
+ {
+ return valid;
+ }
+
+ public void warning(SAXParseException exception) throws SAXException
+ {
+ log.warn(exception.getMessage(), exception);
+ }
+
+ public void error(SAXParseException exception) throws SAXException
+ {
+ log.error("Error in document " + identifier + " at (" + exception.getLineNumber() + "," + exception.getColumnNumber()
+ + ") :" + exception.getMessage());
+ valid = false;
+ }
+
+ public void fatalError(SAXParseException exception) throws SAXException
+ {
+ log.error("Fatal error in document " + identifier + " at (" + exception.getLineNumber() + "," + exception.getColumnNumber()
+ + ") :" + exception.getMessage());
+ valid = false;
+ }
+}
Added: portal/trunk/component/common/src/main/java/org/exoplatform/commons/xml/XMLValidator.java
===================================================================
--- portal/trunk/component/common/src/main/java/org/exoplatform/commons/xml/XMLValidator.java (rev 0)
+++ portal/trunk/component/common/src/main/java/org/exoplatform/commons/xml/XMLValidator.java 2010-02-23 16:55:05 UTC (rev 1824)
@@ -0,0 +1,102 @@
+/*
+ * Copyright (C) 2009 eXo Platform SAS.
+ *
+ * This is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2.1 of
+ * the License, or (at your option) any later version.
+ *
+ * This software is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this software; if not, write to the Free
+ * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ */
+
+package org.exoplatform.commons.xml;
+
+import org.gatein.common.logging.Logger;
+import org.gatein.common.logging.LoggerFactory;
+import org.w3c.dom.Document;
+import org.xml.sax.SAXException;
+
+import javax.xml.parsers.DocumentBuilder;
+import javax.xml.parsers.DocumentBuilderFactory;
+import javax.xml.parsers.ParserConfigurationException;
+import java.io.IOException;
+
+/**
+ * @author <a href="mailto:julien.viet@exoplatform.com">Julien Viet</a>
+ * @version $Revision$
+ */
+public class XMLValidator
+{
+
+ /** . */
+ private final String[] schemas;
+
+ /** . */
+ private final ResourceEntityResolver resolver;
+
+ /** . */
+ private final Logger log = LoggerFactory.getLogger(XMLValidator.class);
+
+ public XMLValidator(Class clazz, String systemId, String resourcePath)
+ {
+ schemas = new String[]{systemId};
+ resolver = new ResourceEntityResolver(clazz, systemId, resourcePath);
+ }
+
+ public String getSystemId()
+ {
+ return schemas[0];
+ }
+
+ /**
+ * Parse and validate the specified resource.
+ *
+ * @param source the source to validate
+ * @return the document when it is valid or null
+ * @throws java.io.IOException any IOException thrown by using the provided URL
+ * @throws NullPointerException if the provided URL is null
+ */
+ public Document validate(DocumentSource source) throws NullPointerException, IOException
+ {
+ if (source == null)
+ {
+ throw new NullPointerException();
+ }
+
+ //
+ DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
+ factory.setAttribute("http://java.sun.com/xml/jaxp/properties/schemaLanguage", "http://www.w3.org/2001/XMLSchema");
+ factory.setAttribute("http://java.sun.com/xml/jaxp/properties/schemaSource", schemas);
+ factory.setNamespaceAware(true);
+ factory.setValidating(true);
+
+ //
+ try
+ {
+ DocumentBuilder builder = factory.newDocumentBuilder();
+ ValidationReporter reporter = new ValidationReporter(log, source.getIdentifier());
+ builder.setErrorHandler(reporter);
+ builder.setEntityResolver(resolver);
+ return builder.parse(source.getStream());
+ }
+ catch (ParserConfigurationException e)
+ {
+ log.error("Got a parser configuration exception when doing XSD validation");
+ return null;
+ }
+ catch (SAXException e)
+ {
+ log.error("Got a sax exception when doing XSD validation");
+ return null;
+ }
+ }
+
+}
Deleted: portal/trunk/component/portal/src/main/java/gatein_resources_1_0.xsd
===================================================================
--- portal/trunk/component/portal/src/main/java/gatein_resources_1_0.xsd 2010-02-23 16:34:27 UTC (rev 1823)
+++ portal/trunk/component/portal/src/main/java/gatein_resources_1_0.xsd 2010-02-23 16:55:05 UTC (rev 1824)
@@ -1,117 +0,0 @@
-<?xml version="1.0"?>
-<!--
-
- Copyright (C) 2009 eXo Platform SAS.
-
- This is free software; you can redistribute it and/or modify it
- under the terms of the GNU Lesser General Public License as
- published by the Free Software Foundation; either version 2.1 of
- the License, or (at your option) any later version.
-
- This software is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- Lesser General Public License for more details.
-
- You should have received a copy of the GNU Lesser General Public
- License along with this software; if not, write to the Free
- Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- 02110-1301 USA, or see the FSF site: http://www.fsf.org.
-
--->
-
-<xs:schema
- targetNamespace="http://www.gatein.org/xml/ns/gatein_resources_1_0.xsd"
- xmlns="http://www.gatein.org/xml/ns/gatein_resources_1_0.xsd"
- xmlns:xs="http://www.w3.org/2001/XMLSchema"
- elementFormDefault="qualified"
- attributeFormDefault="unqualified"
- version="1.0">
-
- <!-- The root element type that contains the various resource declarations -->
- <xs:element name="gatein-resources">
- <xs:complexType>
- <xs:choice minOccurs="0" maxOccurs="unbounded">
- <xs:element name="portal-skin" type="portal-skin" />
- <xs:element name="portlet-skin" type="portlet-skin" />
- <xs:element name="window-style" type="window-style" />
- <xs:element name="javascript" type="javascript" />
- <xs:element name="resource-bundle" type="resource-bundle" />
- </xs:choice>
- </xs:complexType>
- </xs:element>
-
- <!-- Declares a portal skin resource -->
- <xs:complexType name="portal-skin">
- <xs:sequence>
- <xs:element name="skin-name" type="xs:string" minOccurs="1" maxOccurs="1"/>
- <xs:element name="css-path" type="xs:string" minOccurs="1" maxOccurs="1"/>
- <xs:element name="overwrite" type="xs:string" minOccurs="0" maxOccurs="1"/>
- </xs:sequence>
- </xs:complexType>
-
- <!-- Declares a portlet skin resource -->
- <xs:complexType name="portlet-skin">
- <xs:sequence>
- <!-- The portlet application name -->
- <xs:element name="application-name" type="xs:string" minOccurs="1" maxOccurs="1"/>
-
- <!-- The portlet name -->
- <xs:element name="portlet-name" type="xs:string" minOccurs="1" maxOccurs="1"/>
-
- <!-- The name of the skin to load -->
- <xs:element name="skin-name" type="xs:string" minOccurs="1" maxOccurs="1"/>
-
- <!-- The css path of the skin relative to the application context -->
- <xs:element name="css-path" type="xs:string" minOccurs="1" maxOccurs="1"/>
-
- <!-- Overwrite -->
- <xs:element name="overwrite" type="xs:string" minOccurs="0" maxOccurs="1"/>
- </xs:sequence>
- </xs:complexType>
-
- <!-- Declares a window style -->
- <xs:complexType name="window-style" mixed="true">
- <xs:sequence>
-
- <!-- The window style name -->
- <xs:element name="style-name" type="xs:string" minOccurs="1" maxOccurs="1"/>
-
- <!-- The window style theme -->
- <xs:element name="style-theme" type="style-theme" minOccurs="0" maxOccurs="unbounded"/>
- </xs:sequence>
- </xs:complexType>
-
- <!-- The window style theme -->
- <xs:complexType name="style-theme">
- <xs:sequence>
- <!-- The theme name -->
- <xs:element name="theme-name" type="xs:string" minOccurs="1" maxOccurs="1"/>
- </xs:sequence>
- </xs:complexType>
-
- <!-- Declares a javascript resource -->
- <xs:complexType name="javascript">
- <xs:sequence>
- <xs:element name="param" type="param" minOccurs="0" maxOccurs="unbounded"/>
- </xs:sequence>
- </xs:complexType>
-
- <xs:complexType name="param">
- <xs:sequence>
- <!-- The javascript module -->
- <xs:element name="js-module" type="xs:string" minOccurs="1" maxOccurs="1"/>
-
- <!-- The javascript path -->
- <xs:element name="js-path" type="xs:string" minOccurs="1" maxOccurs="1"/>
-
- <!-- The javascript priority -->
- <xs:element name="js-priority" type="xs:string" minOccurs="0" maxOccurs="1"/>
- </xs:sequence>
- </xs:complexType>
-
- <!-- Declares a resource bundle -->
- <xs:complexType name="resource-bundle">
- </xs:complexType>
-
-</xs:schema>
\ No newline at end of file
Added: portal/trunk/component/portal/src/main/java/gatein_resources_1_0.xsd
===================================================================
--- portal/trunk/component/portal/src/main/java/gatein_resources_1_0.xsd (rev 0)
+++ portal/trunk/component/portal/src/main/java/gatein_resources_1_0.xsd 2010-02-23 16:55:05 UTC (rev 1824)
@@ -0,0 +1,117 @@
+<?xml version="1.0"?>
+<!--
+
+ Copyright (C) 2009 eXo Platform SAS.
+
+ This is free software; you can redistribute it and/or modify it
+ under the terms of the GNU Lesser General Public License as
+ published by the Free Software Foundation; either version 2.1 of
+ the License, or (at your option) any later version.
+
+ This software is distributed in the hope that it will be useful,
+ but WITHOUT ANY WARRANTY; without even the implied warranty of
+ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ Lesser General Public License for more details.
+
+ You should have received a copy of the GNU Lesser General Public
+ License along with this software; if not, write to the Free
+ Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+
+-->
+
+<xs:schema
+ targetNamespace="http://www.gatein.org/xml/ns/gatein_resources_1_0.xsd"
+ xmlns="http://www.gatein.org/xml/ns/gatein_resources_1_0.xsd"
+ xmlns:xs="http://www.w3.org/2001/XMLSchema"
+ elementFormDefault="qualified"
+ attributeFormDefault="unqualified"
+ version="1.0">
+
+ <!-- The root element type that contains the various resource declarations -->
+ <xs:element name="gatein-resources">
+ <xs:complexType>
+ <xs:choice minOccurs="0" maxOccurs="unbounded">
+ <xs:element name="portal-skin" type="portal-skin" />
+ <xs:element name="portlet-skin" type="portlet-skin" />
+ <xs:element name="window-style" type="window-style" />
+ <xs:element name="javascript" type="javascript" />
+ <xs:element name="resource-bundle" type="resource-bundle" />
+ </xs:choice>
+ </xs:complexType>
+ </xs:element>
+
+ <!-- Declares a portal skin resource -->
+ <xs:complexType name="portal-skin">
+ <xs:sequence>
+ <xs:element name="skin-name" type="xs:string" minOccurs="1" maxOccurs="1"/>
+ <xs:element name="css-path" type="xs:string" minOccurs="1" maxOccurs="1"/>
+ <xs:element name="overwrite" type="xs:string" minOccurs="0" maxOccurs="1"/>
+ </xs:sequence>
+ </xs:complexType>
+
+ <!-- Declares a portlet skin resource -->
+ <xs:complexType name="portlet-skin">
+ <xs:sequence>
+ <!-- The portlet application name -->
+ <xs:element name="application-name" type="xs:string" minOccurs="1" maxOccurs="1"/>
+
+ <!-- The portlet name -->
+ <xs:element name="portlet-name" type="xs:string" minOccurs="1" maxOccurs="1"/>
+
+ <!-- The name of the skin to load -->
+ <xs:element name="skin-name" type="xs:string" minOccurs="1" maxOccurs="1"/>
+
+ <!-- The css path of the skin relative to the application context -->
+ <xs:element name="css-path" type="xs:string" minOccurs="1" maxOccurs="1"/>
+
+ <!-- Overwrite -->
+ <xs:element name="overwrite" type="xs:string" minOccurs="0" maxOccurs="1"/>
+ </xs:sequence>
+ </xs:complexType>
+
+ <!-- Declares a window style -->
+ <xs:complexType name="window-style" mixed="true">
+ <xs:sequence>
+
+ <!-- The window style name -->
+ <xs:element name="style-name" type="xs:string" minOccurs="1" maxOccurs="1"/>
+
+ <!-- The window style theme -->
+ <xs:element name="style-theme" type="style-theme" minOccurs="0" maxOccurs="unbounded"/>
+ </xs:sequence>
+ </xs:complexType>
+
+ <!-- The window style theme -->
+ <xs:complexType name="style-theme">
+ <xs:sequence>
+ <!-- The theme name -->
+ <xs:element name="theme-name" type="xs:string" minOccurs="1" maxOccurs="1"/>
+ </xs:sequence>
+ </xs:complexType>
+
+ <!-- Declares a javascript resource -->
+ <xs:complexType name="javascript">
+ <xs:sequence>
+ <xs:element name="param" type="param" minOccurs="0" maxOccurs="unbounded"/>
+ </xs:sequence>
+ </xs:complexType>
+
+ <xs:complexType name="param">
+ <xs:sequence>
+ <!-- The javascript module -->
+ <xs:element name="js-module" type="xs:string" minOccurs="1" maxOccurs="1"/>
+
+ <!-- The javascript path -->
+ <xs:element name="js-path" type="xs:string" minOccurs="1" maxOccurs="1"/>
+
+ <!-- The javascript priority -->
+ <xs:element name="js-priority" type="xs:string" minOccurs="0" maxOccurs="1"/>
+ </xs:sequence>
+ </xs:complexType>
+
+ <!-- Declares a resource bundle -->
+ <xs:complexType name="resource-bundle">
+ </xs:complexType>
+
+</xs:schema>
\ No newline at end of file
Modified: portal/trunk/component/portal/src/main/java/org/exoplatform/portal/resource/GateInSkinConfigDeployer.java
===================================================================
--- portal/trunk/component/portal/src/main/java/org/exoplatform/portal/resource/GateInSkinConfigDeployer.java 2010-02-23 16:34:27 UTC (rev 1823)
+++ portal/trunk/component/portal/src/main/java/org/exoplatform/portal/resource/GateInSkinConfigDeployer.java 2010-02-23 16:55:05 UTC (rev 1824)
@@ -19,16 +19,17 @@
package org.exoplatform.portal.resource;
+import org.exoplatform.commons.xml.DocumentSource;
import org.exoplatform.container.PortalContainer;
import org.exoplatform.container.RootContainer.PortalContainerPostInitTask;
import org.exoplatform.portal.resource.config.xml.SkinConfigParser;
-import org.exoplatform.services.log.ExoLogger;
-import org.exoplatform.services.log.Log;
+import org.gatein.common.logging.Logger;
+import org.gatein.common.logging.LoggerFactory;
import org.gatein.wci.WebAppEvent;
import org.gatein.wci.WebAppLifeCycleEvent;
-import java.io.IOException;
import java.io.InputStream;
+import java.net.URL;
import javax.servlet.ServletContext;
@@ -43,12 +44,15 @@
public class GateInSkinConfigDeployer extends AbstractResourceHandler
{
+ /** . */
+ private static final Logger log = LoggerFactory.getLogger(GateInSkinConfigDeployer.class);
+
+ /** . */
private final SkinService skinService;
+ /** . */
private static final String GATEIN_CONFIG_RESOURCE = "/WEB-INF/gatein-resources.xml";
- private static Log LOG = ExoLogger.getExoLogger(GateInSkinConfigDeployer.class);
-
/**
* The name of the portal container
*/
@@ -96,7 +100,7 @@
}
catch (Exception ex)
{
- LOG.error("An error occurs while registering '" + GATEIN_CONFIG_RESOURCE + "' from the context '"
+ log.error("An error occurs while registering '" + GATEIN_CONFIG_RESOURCE + "' from the context '"
+ (scontext == null ? "unknown" : scontext.getServletContextName()) + "'", ex);
}
}
@@ -105,30 +109,23 @@
private void register(ServletContext scontext, PortalContainer container)
{
- InputStream is = null;
+ URL url;
try
{
- is = scontext.getResourceAsStream(GATEIN_CONFIG_RESOURCE);
- SkinConfigParser.processConfigResource(is, skinService, scontext);
+ url = scontext.getResource(GATEIN_CONFIG_RESOURCE);
+ if (url != null)
+ {
+ SkinConfigParser.processConfigResource(DocumentSource.create(url), skinService, scontext);
+ }
+ else
+ {
+ log.debug("No " + GATEIN_CONFIG_RESOURCE + " found in web application " + scontext.getContextPath());
+ }
}
catch (Exception ex)
{
- LOG.error("An error occurs while registering '" + GATEIN_CONFIG_RESOURCE + "' from the context '"
+ log.error("An error occurs while registering '" + GATEIN_CONFIG_RESOURCE + "' from the context '"
+ (scontext == null ? "unknown" : scontext.getServletContextName()) + "'", ex);
}
- finally
- {
- if (is != null)
- {
- try
- {
- is.close();
- }
- catch (IOException e)
- {
- // ignore me
- }
- }
- }
}
}
Modified: portal/trunk/component/portal/src/main/java/org/exoplatform/portal/resource/config/xml/SkinConfigParser.java
===================================================================
--- portal/trunk/component/portal/src/main/java/org/exoplatform/portal/resource/config/xml/SkinConfigParser.java 2010-02-23 16:34:27 UTC (rev 1823)
+++ portal/trunk/component/portal/src/main/java/org/exoplatform/portal/resource/config/xml/SkinConfigParser.java 2010-02-23 16:55:05 UTC (rev 1824)
@@ -19,6 +19,8 @@
package org.exoplatform.portal.resource.config.xml;
+import org.exoplatform.commons.xml.DocumentSource;
+import org.exoplatform.commons.xml.XMLValidator;
import org.exoplatform.portal.resource.SkinService;
import org.exoplatform.portal.resource.config.tasks.AbstractSkinTask;
import org.exoplatform.web.resource.config.xml.GateinResource;
@@ -26,15 +28,12 @@
import org.w3c.dom.Element;
import org.w3c.dom.NodeList;
-import java.io.InputStream;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.servlet.ServletContext;
-import javax.xml.parsers.DocumentBuilder;
-import javax.xml.parsers.DocumentBuilderFactory;
/**
*
@@ -47,6 +46,18 @@
public class SkinConfigParser
{
+ /** . */
+ public static final String GATEIN_RESOURCES_1_0_SYSTEM_ID = "http://www.gatein.org/xml/ns/gatein_resources_1_0.xsd";
+
+ /** . */
+ private static final String GATEIN_RESOURCE_1_0_XSD_PATH = "gatein_resources_1_0.xsd";
+
+ /** . */
+ private static final XMLValidator VALIDATOR = new XMLValidator(
+ SkinConfigParser.class,
+ GATEIN_RESOURCES_1_0_SYSTEM_ID,
+ GATEIN_RESOURCE_1_0_XSD_PATH);
+
private final static Map<String, AbstractTaskXMLBinding> allBindings = new HashMap<String, AbstractTaskXMLBinding>();
static
@@ -56,9 +67,9 @@
allBindings.put(GateinResource.WINDOW_STYLE_TAG, new AbstractTaskXMLBinding.ThemeTaskXMLBinding());
}
- public static void processConfigResource(InputStream is, SkinService skinService, ServletContext scontext)
+ public static void processConfigResource(DocumentSource source, SkinService skinService, ServletContext scontext)
{
- List<AbstractSkinTask> allTasks = fetchTasks(is);
+ List<AbstractSkinTask> allTasks = fetchTasks(source);
if (allTasks != null)
{
for (AbstractSkinTask task : allTasks)
@@ -68,12 +79,11 @@
}
}
- private static List<AbstractSkinTask> fetchTasks(InputStream is)
+ private static List<AbstractSkinTask> fetchTasks(DocumentSource source)
{
try
{
- DocumentBuilder docBuilder = DocumentBuilderFactory.newInstance().newDocumentBuilder();
- Document document = docBuilder.parse(is);
+ Document document = VALIDATOR.validate(source);
return fetchTasksFromXMLConfig(document);
}
catch (Exception ex)
@@ -94,12 +104,6 @@
return tasks;
}
- /**
- *
- * @param tagName
- * @param rootElement
- * @param tasks
- */
private static void fetchTasksByTagName(String tagName, Element rootElement, List<AbstractSkinTask> tasks)
{
AbstractTaskXMLBinding binding = allBindings.get(tagName);
Modified: portal/trunk/examples/extension/war/src/main/webapp/WEB-INF/gatein-resources.xml
===================================================================
--- portal/trunk/examples/extension/war/src/main/webapp/WEB-INF/gatein-resources.xml 2010-02-23 16:34:27 UTC (rev 1823)
+++ portal/trunk/examples/extension/war/src/main/webapp/WEB-INF/gatein-resources.xml 2010-02-23 16:55:05 UTC (rev 1824)
@@ -21,7 +21,7 @@
-->
<gatein-resources
xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
- xsi:schemaLocation="http://www.gatein.org/xml/ns/gatein_resources_1_0.xsd"
+ xsi:schemaLocation="http://www.gatein.org/xml/ns/gatein_resources_1_0.xsd http://www.gatein.org/xml/ns/gatein_resources_1_0.xsd"
xmlns="http://www.gatein.org/xml/ns/gatein_resources_1_0.xsd">
<portlet-skin>
Modified: portal/trunk/examples/portal/war/src/main/webapp/WEB-INF/gatein-resources.xml
===================================================================
--- portal/trunk/examples/portal/war/src/main/webapp/WEB-INF/gatein-resources.xml 2010-02-23 16:34:27 UTC (rev 1823)
+++ portal/trunk/examples/portal/war/src/main/webapp/WEB-INF/gatein-resources.xml 2010-02-23 16:55:05 UTC (rev 1824)
@@ -22,7 +22,7 @@
<gatein-resources
xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
- xsi:schemaLocation="http://www.gatein.org/xml/ns/gatein_resources_1_0.xsd"
+ xsi:schemaLocation="http://www.gatein.org/xml/ns/gatein_resources_1_0.xsd http://www.gatein.org/xml/ns/gatein_resources_1_0.xsd"
xmlns="http://www.gatein.org/xml/ns/gatein_resources_1_0.xsd">
<portlet-skin>
Modified: portal/trunk/pom.xml
===================================================================
--- portal/trunk/pom.xml 2010-02-23 16:34:27 UTC (rev 1823)
+++ portal/trunk/pom.xml 2010-02-23 16:55:05 UTC (rev 1824)
@@ -495,6 +495,7 @@
<includes>
<include>**/*.properties</include>
<include>**/*.xml</include>
+ <include>**/*.xsd</include>
</includes>
</resource>
</resources>
Modified: portal/trunk/portlet/dashboard/src/main/webapp/WEB-INF/gatein-resources.xml
===================================================================
--- portal/trunk/portlet/dashboard/src/main/webapp/WEB-INF/gatein-resources.xml 2010-02-23 16:34:27 UTC (rev 1823)
+++ portal/trunk/portlet/dashboard/src/main/webapp/WEB-INF/gatein-resources.xml 2010-02-23 16:55:05 UTC (rev 1824)
@@ -22,7 +22,7 @@
<gatein-resources
xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
- xsi:schemaLocation="http://www.gatein.org/xml/ns/gatein_resources_1_0.xsd"
+ xsi:schemaLocation="http://www.gatein.org/xml/ns/gatein_resources_1_0.xsd http://www.gatein.org/xml/ns/gatein_resources_1_0.xsd"
xmlns="http://www.gatein.org/xml/ns/gatein_resources_1_0.xsd">
<!-- GadgetPortlet skins -->
Modified: portal/trunk/portlet/exoadmin/src/main/webapp/WEB-INF/gatein-resources.xml
===================================================================
--- portal/trunk/portlet/exoadmin/src/main/webapp/WEB-INF/gatein-resources.xml 2010-02-23 16:34:27 UTC (rev 1823)
+++ portal/trunk/portlet/exoadmin/src/main/webapp/WEB-INF/gatein-resources.xml 2010-02-23 16:55:05 UTC (rev 1824)
@@ -22,7 +22,7 @@
<gatein-resources
xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
- xsi:schemaLocation="http://www.gatein.org/xml/ns/gatein_resources_1_0.xsd"
+ xsi:schemaLocation="http://www.gatein.org/xml/ns/gatein_resources_1_0.xsd http://www.gatein.org/xml/ns/gatein_resources_1_0.xsd"
xmlns="http://www.gatein.org/xml/ns/gatein_resources_1_0.xsd">
Modified: portal/trunk/portlet/web/src/main/webapp/WEB-INF/gatein-resources.xml
===================================================================
--- portal/trunk/portlet/web/src/main/webapp/WEB-INF/gatein-resources.xml 2010-02-23 16:34:27 UTC (rev 1823)
+++ portal/trunk/portlet/web/src/main/webapp/WEB-INF/gatein-resources.xml 2010-02-23 16:55:05 UTC (rev 1824)
@@ -22,7 +22,7 @@
<gatein-resources
xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
- xsi:schemaLocation="http://www.gatein.org/xml/ns/gatein_resources_1_0.xsd"
+ xsi:schemaLocation="http://www.gatein.org/xml/ns/gatein_resources_1_0.xsd http://www.gatein.org/xml/ns/gatein_resources_1_0.xsd"
xmlns="http://www.gatein.org/xml/ns/gatein_resources_1_0.xsd">
<!-- BannerPortlet skins -->
Modified: portal/trunk/web/eXoResources/src/main/webapp/WEB-INF/gatein-resources.xml
===================================================================
--- portal/trunk/web/eXoResources/src/main/webapp/WEB-INF/gatein-resources.xml 2010-02-23 16:34:27 UTC (rev 1823)
+++ portal/trunk/web/eXoResources/src/main/webapp/WEB-INF/gatein-resources.xml 2010-02-23 16:55:05 UTC (rev 1824)
@@ -19,7 +19,10 @@
02110-1301 USA, or see the FSF site: http://www.fsf.org.
-->
-<gatein-resources xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="http://www.gatein.org/xml/ns/gatein_resources_1_0.xsd" xmlns="http://www.gatein.org/xml/ns/gatein_resources_1_0.xsd">
+<gatein-resources
+ xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
+ xsi:schemaLocation="http://www.gatein.org/xml/ns/gatein_resources_1_0.xsd http://www.gatein.org/xml/ns/gatein_resources_1_0.xsd"
+ xmlns="http://www.gatein.org/xml/ns/gatein_resources_1_0.xsd">
<portal-skin>
<skin-name>Default</skin-name>
Modified: portal/trunk/web/portal/src/main/webapp/WEB-INF/gatein-resources.xml
===================================================================
--- portal/trunk/web/portal/src/main/webapp/WEB-INF/gatein-resources.xml 2010-02-23 16:34:27 UTC (rev 1823)
+++ portal/trunk/web/portal/src/main/webapp/WEB-INF/gatein-resources.xml 2010-02-23 16:55:05 UTC (rev 1824)
@@ -22,7 +22,7 @@
<gatein-resources
xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
- xsi:schemaLocation="http://www.gatein.org/xml/ns/gatein_resources_1_0.xsd"
+ xsi:schemaLocation="http://www.gatein.org/xml/ns/gatein_resources_1_0.xsd http://www.gatein.org/xml/ns/gatein_resources_1_0.xsd"
xmlns="http://www.gatein.org/xml/ns/gatein_resources_1_0.xsd">
<portlet-skin>
14 years, 10 months
gatein SVN: r1823 - maven/packager/trunk/src/main/javascript/eXo/server.
by do-not-reply@jboss.org
Author: thomas.heute(a)jboss.com
Date: 2010-02-23 11:34:27 -0500 (Tue, 23 Feb 2010)
New Revision: 1823
Modified:
maven/packager/trunk/src/main/javascript/eXo/server/JbossEar.js
Log:
GTNMAVEN-5: Add jcip-annotations.jar in the 'default' configuration
Modified: maven/packager/trunk/src/main/javascript/eXo/server/JbossEar.js
===================================================================
--- maven/packager/trunk/src/main/javascript/eXo/server/JbossEar.js 2010-02-23 15:42:06 UTC (rev 1822)
+++ maven/packager/trunk/src/main/javascript/eXo/server/JbossEar.js 2010-02-23 16:34:27 UTC (rev 1823)
@@ -149,6 +149,10 @@
}
}
+ // Copy jcip-annotations.jar in "default" configuration
+ // See JBAS-6437
+ eXo.core.IOUtil.cp(this.serverHome + "/server/all/lib/jcip-annotations.jar", this.serverHome + "/server/default/lib");
+
// Copy configuration
new java.io.File(this.gateInConfigDir).mkdir();
eXo.core.IOUtil.cp(eXo.env.currentDir + "/../../component/common/src/main/java/conf/configuration-jboss.properties", this.gateInConfigDir + "/configuration.properties")
14 years, 10 months
gatein SVN: r1822 - portal/trunk/component/wsrp/src/main/java/org/gatein/portal/wsrp.
by do-not-reply@jboss.org
Author: mwringe
Date: 2010-02-23 10:42:06 -0500 (Tue, 23 Feb 2010)
New Revision: 1822
Modified:
portal/trunk/component/wsrp/src/main/java/org/gatein/portal/wsrp/ExoKernelIntegration.java
Log:
Add missing NodeHierarchyCreator dependency, without this it can cause the portal to not deploy due to a missing jcr repository. This issue may not occur when using the Sun JDK, but does when using the IBM one (GTNPORTAL-636).
Modified: portal/trunk/component/wsrp/src/main/java/org/gatein/portal/wsrp/ExoKernelIntegration.java
===================================================================
--- portal/trunk/component/portal/src/main/java/gatein_resources_1_0.xsd (rev 0)
+++ portal/trunk/component/portal/src/main/java/gatein_resources_1_0.xsd 2010-02-23 14:50:43 UTC (rev 1820)
@@ -0,0 +1,117 @@
+<?xml version="1.0"?>
+<!--
+
+ Copyright (C) 2009 eXo Platform SAS.
+
+ This is free software; you can redistribute it and/or modify it
+ under the terms of the GNU Lesser General Public License as
+ published by the Free Software Foundation; either version 2.1 of
+ the License, or (at your option) any later version.
+
+ This software is distributed in the hope that it will be useful,
+ but WITHOUT ANY WARRANTY; without even the implied warranty of
+ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ Lesser General Public License for more details.
+
+ You should have received a copy of the GNU Lesser General Public
+ License along with this software; if not, write to the Free
+ Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+
+-->
+
+<xs:schema
+ targetNamespace="http://www.gatein.org/xml/ns/gatein_resources_1_0.xsd"
+ xmlns="http://www.gatein.org/xml/ns/gatein_resources_1_0.xsd"
+ xmlns:xs="http://www.w3.org/2001/XMLSchema"
+ elementFormDefault="qualified"
+ attributeFormDefault="unqualified"
+ version="1.0">
+
+ <!-- The root element type that contains the various resource declarations -->
+ <xs:element name="gatein-resources">
+ <xs:complexType>
+ <xs:choice minOccurs="0" maxOccurs="unbounded">
+ <xs:element name="portal-skin" type="portal-skin" />
+ <xs:element name="portlet-skin" type="portlet-skin" />
+ <xs:element name="window-style" type="window-style" />
+ <xs:element name="javascript" type="javascript" />
+ <xs:element name="resource-bundle" type="resource-bundle" />
+ </xs:choice>
+ </xs:complexType>
+ </xs:element>
+
+ <!-- Declares a portal skin resource -->
+ <xs:complexType name="portal-skin">
+ <xs:sequence>
+ <xs:element name="skin-name" type="xs:string" minOccurs="1" maxOccurs="1"/>
+ <xs:element name="css-path" type="xs:string" minOccurs="1" maxOccurs="1"/>
+ <xs:element name="overwrite" type="xs:string" minOccurs="0" maxOccurs="1"/>
+ </xs:sequence>
+ </xs:complexType>
+
+ <!-- Declares a portlet skin resource -->
+ <xs:complexType name="portlet-skin">
+ <xs:sequence>
+ <!-- The portlet application name -->
+ <xs:element name="application-name" type="xs:string" minOccurs="1" maxOccurs="1"/>
+
+ <!-- The portlet name -->
+ <xs:element name="portlet-name" type="xs:string" minOccurs="1" maxOccurs="1"/>
+
+ <!-- The name of the skin to load -->
+ <xs:element name="skin-name" type="xs:string" minOccurs="1" maxOccurs="1"/>
+
+ <!-- The css path of the skin relative to the application context -->
+ <xs:element name="css-path" type="xs:string" minOccurs="1" maxOccurs="1"/>
+
+ <!-- Overwrite -->
+ <xs:element name="overwrite" type="xs:string" minOccurs="0" maxOccurs="1"/>
+ </xs:sequence>
+ </xs:complexType>
+
+ <!-- Declares a window style -->
+ <xs:complexType name="window-style" mixed="true">
+ <xs:sequence>
+
+ <!-- The window style name -->
+ <xs:element name="style-name" type="xs:string" minOccurs="1" maxOccurs="1"/>
+
+ <!-- The window style theme -->
+ <xs:element name="style-theme" type="style-theme" minOccurs="0" maxOccurs="unbounded"/>
+ </xs:sequence>
+ </xs:complexType>
+
+ <!-- The window style theme -->
+ <xs:complexType name="style-theme">
+ <xs:sequence>
+ <!-- The theme name -->
+ <xs:element name="theme-name" type="xs:string" minOccurs="1" maxOccurs="1"/>
+ </xs:sequence>
+ </xs:complexType>
+
+ <!-- Declares a javascript resource -->
+ <xs:complexType name="javascript">
+ <xs:sequence>
+ <xs:element name="param" type="param" minOccurs="0" maxOccurs="unbounded"/>
+ </xs:sequence>
+ </xs:complexType>
+
+ <xs:complexType name="param">
+ <xs:sequence>
+ <!-- The javascript module -->
+ <xs:element name="js-module" type="xs:string" minOccurs="1" maxOccurs="1"/>
+
+ <!-- The javascript path -->
+ <xs:element name="js-path" type="xs:string" minOccurs="1" maxOccurs="1"/>
+
+ <!-- The javascript priority -->
+ <xs:element name="js-priority" type="xs:string" minOccurs="0" maxOccurs="1"/>
+ </xs:sequence>
+ </xs:complexType>
+
+ <!-- Declares a resource bundle -->
+ <xs:complexType name="resource-bundle">
+ </xs:complexType>
+
+</xs:schema>
\ No newline at end of file
Modified: portal/trunk/examples/extension/war/src/main/webapp/WEB-INF/gatein-resources.xml
===================================================================
--- portal/trunk/examples/extension/war/src/main/webapp/WEB-INF/gatein-resources.xml 2010-02-23 14:50:07 UTC (rev 1819)
+++ portal/trunk/examples/extension/war/src/main/webapp/WEB-INF/gatein-resources.xml 2010-02-23 14:50:43 UTC (rev 1820)
@@ -28,9 +28,9 @@
<application-name>web</application-name>
<portlet-name>HomePagePortlet</portlet-name>
<skin-name>Default</skin-name>
- <overwrite>false</overwrite>
<css-path>/templates/skin/webui/component/UIHomePagePortlet/DefaultStylesheet.css</css-path>
- </portlet-skin>
+ <overwrite>false</overwrite>
+ </portlet-skin>
</gatein-resources>
Deleted: portal/trunk/web/portal/src/main/webapp/WEB-INF/gatein_resources_1_0.xsd
===================================================================
--- portal/trunk/web/portal/src/main/webapp/WEB-INF/gatein_resources_1_0.xsd 2010-02-23 14:50:07 UTC (rev 1819)
+++ portal/trunk/web/portal/src/main/webapp/WEB-INF/gatein_resources_1_0.xsd 2010-02-23 14:50:43 UTC (rev 1820)
@@ -1,86 +0,0 @@
-<?xml version="1.0"?>
-<!--
-
- Copyright (C) 2009 eXo Platform SAS.
-
- This is free software; you can redistribute it and/or modify it
- under the terms of the GNU Lesser General Public License as
- published by the Free Software Foundation; either version 2.1 of
- the License, or (at your option) any later version.
-
- This software is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- Lesser General Public License for more details.
-
- You should have received a copy of the GNU Lesser General Public
- License along with this software; if not, write to the Free
- Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- 02110-1301 USA, or see the FSF site: http://www.fsf.org.
-
--->
-
-<xs:schema xmlns:xs="http://www.w3.org/2001/XMLSchema"
- targetNamespace="http://www.w3schools.com"
- xmlns="http://www.w3schools.com"
- elementFormDefault="qualified">
-
- <xs:element name="gatein-resources">
- <xs:complexType>
- <xs:sequence>
- <xs:element name="portal-skin" type="portal-skin" />
- <xs:element name="portlet-skin" type="portlet-skin" />
- <xs:element name="window-style" type="window-style" />
- <xs:element name="javascript" type="javascript" />
- <xs:element name="resource-bundle" type="resource-bundle" />
- </xs:sequence>
- </xs:complexType>
- </xs:element>
-
- <xs:complexType name="portal-skin">
- <xs:sequence>
- <xs:element name="skin-name" type="xs:string" />
- <xs:element name="css-path" type="xs:string" />
- <xs:element name="overwrite" type="xs:string" />
- </xs:sequence>
- </xs:complexType>
-
- <xs:complexType name="portlet-skin">
- <xs:sequence>
- <xs:element name="application-name" type="xs:string" />
- <xs:element name="portlet-name" type="xs:string" />
- <xs:element name="skin-name" type="xs:string" />
- <xs:element name="css-path" type="xs:string" />
- <xs:element name="overwrite" type="xs:string" />
- </xs:sequence>
- </xs:complexType>
-
- <xs:complexType name="window-style" mixed="true">
- <xs:sequence>
- <xs:element name="style-name" type="xs:string" />
- <xs:element name="style-theme" type="style-theme" />
- </xs:sequence>
- </xs:complexType>
-
- <xs:complexType name="style-theme">
- <xs:sequence>
- <xs:element name="theme-name" type="xs:string" />
- </xs:sequence>
- </xs:complexType>
-
- <xs:complexType name="javascript">
- <xs:sequence>
- <xs:element name="param" type="xs:param" />
- </xs:sequence>
- </xs:complexType>
-
- <xs:complexType name="param">
- <xs:sequence>
- <xs:element name="js-module" type="xs:string" />
- <xs:element name="js-path" type="xs:string" />
- </xs:sequence>
- </xs:complexType>
-
- <xs:complexType name="resource-bundle">
- </xs:complexType>
-</xs:schema>
\ No newline at end of file
14 years, 10 months
gatein SVN: r1819 - portal/trunk/server/jboss/patch-ear/src/main/jboss/bin.
by do-not-reply@jboss.org
Author: thomas.heute(a)jboss.com
Date: 2010-02-23 09:50:07 -0500 (Tue, 23 Feb 2010)
New Revision: 1819
Modified:
portal/trunk/server/jboss/patch-ear/src/main/jboss/bin/run.conf
portal/trunk/server/jboss/patch-ear/src/main/jboss/bin/run.conf.bat
Log:
Set default memory values
Modified: portal/trunk/server/jboss/patch-ear/src/main/jboss/bin/run.conf
===================================================================
--- portal/trunk/server/jboss/patch-ear/src/main/jboss/bin/run.conf 2010-02-23 13:54:27 UTC (rev 1818)
+++ portal/trunk/server/jboss/patch-ear/src/main/jboss/bin/run.conf 2010-02-23 14:50:07 UTC (rev 1819)
@@ -42,7 +42,7 @@
# Specify options to pass to the Java VM.
#
if [ "x$JAVA_OPTS" = "x" ]; then
- JAVA_OPTS="-Xms256m -Xmx768m -XX:MaxPermSize=768m -Dorg.jboss.resolver.warning=true -Dsun.rmi.dgc.client.gcInterval=3600000 -Dsun.rmi.dgc.server.gcInterval=3600000"
+ JAVA_OPTS="-Xms512m -Xmx768m -XX:MaxPermSize=256m -XX:-UseGCOverheadLimit -Dorg.jboss.resolver.warning=true -Dsun.rmi.dgc.client.gcInterval=3600000 -Dsun.rmi.dgc.server.gcInterval=3600000"
fi
# Sample JPDA settings for remote socket debugging
Modified: portal/trunk/server/jboss/patch-ear/src/main/jboss/bin/run.conf.bat
===================================================================
--- portal/trunk/server/jboss/patch-ear/src/main/jboss/bin/run.conf.bat 2010-02-23 13:54:27 UTC (rev 1818)
+++ portal/trunk/server/jboss/patch-ear/src/main/jboss/bin/run.conf.bat 2010-02-23 14:50:07 UTC (rev 1819)
@@ -40,7 +40,7 @@
rem #
rem # JVM memory allocation pool parameters - modify as appropriate.
-set "JAVA_OPTS=-Xms256M -Xmx768M -XX:MaxPermSize=768M"
+set "JAVA_OPTS=-Xms512M -Xmx768M -XX:MaxPermSize=256M -XX:-UseGCOverheadLimit"
rem # Reduce the RMI GCs to once per hour for Sun JVMs.
set "JAVA_OPTS=%JAVA_OPTS% -Dsun.rmi.dgc.client.gcInterval=3600000 -Dsun.rmi.dgc.server.gcInterval=3600000"
14 years, 10 months
gatein SVN: r1818 - portal/branches/EPP_5_0_0_ER03_Branch/component/identity.
by do-not-reply@jboss.org
Author: mpodolin
Date: 2010-02-23 08:54:27 -0500 (Tue, 23 Feb 2010)
New Revision: 1818
Modified:
portal/branches/EPP_5_0_0_ER03_Branch/component/identity/pom.xml
Log:
EPP ER3 productization patch
Modified: portal/branches/EPP_5_0_0_ER03_Branch/component/identity/pom.xml
===================================================================
--- portal/branches/EPP_5_0_0_ER03_Branch/component/identity/pom.xml 2010-02-23 13:52:43 UTC (rev 1817)
+++ portal/branches/EPP_5_0_0_ER03_Branch/component/identity/pom.xml 2010-02-23 13:54:27 UTC (rev 1818)
@@ -86,5 +86,11 @@
<scope>test</scope>
</dependency>
+ <dependency>
+ <groupId>org.hibernate</groupId>
+ <artifactId>hibernate-jbosscache2</artifactId>
+ <version>3.3.2.GA</version>
+ <scope>runtime</scope>
+ </dependency>
</dependencies>
</project>
14 years, 10 months
gatein SVN: r1817 - portal/branches/EPP_5_0_0_ER03_Branch/packaging/module/src/main/javascript.
by do-not-reply@jboss.org
Author: mpodolin
Date: 2010-02-23 08:52:43 -0500 (Tue, 23 Feb 2010)
New Revision: 1817
Modified:
portal/branches/EPP_5_0_0_ER03_Branch/packaging/module/src/main/javascript/portal.packaging.module.js
Log:
EPP ER3 productization patch
Modified: portal/branches/EPP_5_0_0_ER03_Branch/packaging/module/src/main/javascript/portal.packaging.module.js
===================================================================
--- portal/branches/EPP_5_0_0_ER03_Branch/packaging/module/src/main/javascript/portal.packaging.module.js 2010-02-23 13:18:14 UTC (rev 1816)
+++ portal/branches/EPP_5_0_0_ER03_Branch/packaging/module/src/main/javascript/portal.packaging.module.js 2010-02-23 13:52:43 UTC (rev 1817)
@@ -130,7 +130,8 @@
addDependency(new Project("org.picketlink.idm", "picketlink-idm-api", "jar", idmVersion)).
addDependency(new Project("org.picketlink.idm", "picketlink-idm-spi", "jar", idmVersion)).
addDependency(new Project("org.picketlink.idm", "picketlink-idm-hibernate", "jar", idmVersion)).
- addDependency(new Project("org.picketlink.idm", "picketlink-idm-ldap", "jar", idmVersion));
+ addDependency(new Project("org.picketlink.idm", "picketlink-idm-ldap", "jar", idmVersion)).
+ addDependency(new Project("org.hibernate", "hibernate-jbosscache2", "jar", "3.3.2.GA"));
module.component.applicationRegistry =
new Project("org.exoplatform.portal", "exo.portal.component.application-registry", "jar", module.version).
14 years, 10 months
gatein SVN: r1816 - in portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF: classes/picketlink-idm/sybase-mappings and 2 other directories.
by do-not-reply@jboss.org
Author: mpodolin
Date: 2010-02-23 08:18:14 -0500 (Tue, 23 Feb 2010)
New Revision: 1816
Modified:
portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/mappings/HibernateIdentityObject.hbm.xml
portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/mappings/HibernateIdentityObjectAttribute.hbm.xml
portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/mappings/HibernateIdentityObjectAttributeBinaryValue.hbm.xml
portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/mappings/HibernateIdentityObjectCredential.hbm.xml
portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/mappings/HibernateIdentityObjectCredentialBinaryValue.hbm.xml
portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/mappings/HibernateIdentityObjectCredentialType.hbm.xml
portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/mappings/HibernateIdentityObjectRelationship.hbm.xml
portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/mappings/HibernateIdentityObjectRelationshipName.hbm.xml
portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/mappings/HibernateIdentityObjectRelationshipType.hbm.xml
portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/mappings/HibernateIdentityObjectType.hbm.xml
portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/mappings/HibernateRealm.hbm.xml
portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/sybase-mappings/HibernateIdentityObject.hbm.xml
portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/sybase-mappings/HibernateIdentityObjectAttribute.hbm.xml
portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/sybase-mappings/HibernateIdentityObjectAttributeBinaryValue.hbm.xml
portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/sybase-mappings/HibernateIdentityObjectCredential.hbm.xml
portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/sybase-mappings/HibernateIdentityObjectCredentialBinaryValue.hbm.xml
portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/sybase-mappings/HibernateIdentityObjectCredentialType.hbm.xml
portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/sybase-mappings/HibernateIdentityObjectRelationship.hbm.xml
portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/sybase-mappings/HibernateIdentityObjectRelationshipName.hbm.xml
portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/sybase-mappings/HibernateIdentityObjectRelationshipType.hbm.xml
portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/sybase-mappings/HibernateIdentityObjectType.hbm.xml
portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/sybase-mappings/HibernateRealm.hbm.xml
portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/conf/jcr/jcr-configuration.xml
portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/conf/organization/idm-configuration.xml
Log:
EPP ER3 productization changes
Modified: portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/mappings/HibernateIdentityObject.hbm.xml
===================================================================
--- portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/mappings/HibernateIdentityObject.hbm.xml 2010-02-23 09:42:10 UTC (rev 1815)
+++ portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/mappings/HibernateIdentityObject.hbm.xml 2010-02-23 13:18:14 UTC (rev 1816)
@@ -4,7 +4,7 @@
<hibernate-mapping>
<class name="org.picketlink.idm.impl.model.hibernate.HibernateIdentityObject"
table="jbid_io">
- <cache usage="read-write"/>
+ <cache usage="transactional"/>
<id name="id"
type="java.lang.Long"
access="field">
@@ -16,7 +16,7 @@
cascade="all, delete-orphan"
lazy="extra"
fetch="subselect">
- <cache usage="read-write"/>
+ <cache usage="transactional"/>
<key>
<column name="IDENTITY_OBJECT_ID" />
</key>
@@ -27,7 +27,7 @@
cascade="all, delete-orphan"
lazy="extra"
fetch="subselect">
- <cache usage="read-write"/>
+ <cache usage="transactional"/>
<key>
<column name="IDENTITY_OBJECT_ID" />
</key>
@@ -37,7 +37,7 @@
inverse="true"
lazy="extra"
fetch="subselect">
- <cache usage="read-write"/>
+ <cache usage="transactional"/>
<key>
<column name="FROM_IDENTITY" />
</key>
@@ -65,7 +65,7 @@
cascade="all, delete-orphan"
lazy="extra"
fetch="subselect">
- <cache usage="read-write"/>
+ <cache usage="transactional"/>
<key column="PROP_ID"/>
<map-key type="string"
column="PROP_NAME"/>
@@ -85,7 +85,7 @@
inverse="true"
lazy="extra"
fetch="subselect">
- <cache usage="read-write"/>
+ <cache usage="transactional"/>
<key>
<column name="TO_IDENTITY" />
</key>
Modified: portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/mappings/HibernateIdentityObjectAttribute.hbm.xml
===================================================================
--- portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/mappings/HibernateIdentityObjectAttribute.hbm.xml 2010-02-23 09:42:10 UTC (rev 1815)
+++ portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/mappings/HibernateIdentityObjectAttribute.hbm.xml 2010-02-23 13:18:14 UTC (rev 1816)
@@ -4,7 +4,7 @@
<hibernate-mapping>
<class name="org.picketlink.idm.impl.model.hibernate.HibernateIdentityObjectAttribute"
table="jbid_io_attr">
- <cache usage="read-write"/>
+ <cache usage="transactional"/>
<id name="id"
type="java.lang.Long"
access="field">
@@ -37,7 +37,7 @@
access="field"
lazy="extra"
fetch="subselect">
- <cache usage="read-write"/>
+ <cache usage="transactional"/>
<key column="TEXT_ATTR_VALUE_ID"/>
<element type="string"
column="ATTR_VALUE"/>
Modified: portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/mappings/HibernateIdentityObjectAttributeBinaryValue.hbm.xml
===================================================================
--- portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/mappings/HibernateIdentityObjectAttributeBinaryValue.hbm.xml 2010-02-23 09:42:10 UTC (rev 1815)
+++ portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/mappings/HibernateIdentityObjectAttributeBinaryValue.hbm.xml 2010-02-23 13:18:14 UTC (rev 1816)
@@ -4,7 +4,7 @@
<hibernate-mapping>
<class name="org.picketlink.idm.impl.model.hibernate.HibernateIdentityObjectAttributeBinaryValue"
table="jbid_attr_bin_value">
- <cache usage="read-write"/>
+ <cache usage="transactional"/>
<id name="id"
type="java.lang.Long"
access="field">
Modified: portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/mappings/HibernateIdentityObjectCredential.hbm.xml
===================================================================
--- portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/mappings/HibernateIdentityObjectCredential.hbm.xml 2010-02-23 09:42:10 UTC (rev 1815)
+++ portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/mappings/HibernateIdentityObjectCredential.hbm.xml 2010-02-23 13:18:14 UTC (rev 1816)
@@ -4,7 +4,7 @@
<hibernate-mapping>
<class name="org.picketlink.idm.impl.model.hibernate.HibernateIdentityObjectCredential"
table="jbid_io_creden">
- <cache usage="read-write"/>
+ <cache usage="transactional"/>
<id name="id"
type="java.lang.Long"
@@ -35,7 +35,7 @@
cascade="all, delete-orphan"
lazy="extra"
fetch="subselect">
- <cache usage="read-write"/>
+ <cache usage="transactional"/>
<key column="PROP_ID"/>
<map-key type="string"
column="PROP_NAME"/>
Modified: portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/mappings/HibernateIdentityObjectCredentialBinaryValue.hbm.xml
===================================================================
--- portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/mappings/HibernateIdentityObjectCredentialBinaryValue.hbm.xml 2010-02-23 09:42:10 UTC (rev 1815)
+++ portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/mappings/HibernateIdentityObjectCredentialBinaryValue.hbm.xml 2010-02-23 13:18:14 UTC (rev 1816)
@@ -4,7 +4,7 @@
<hibernate-mapping>
<class name="org.picketlink.idm.impl.model.hibernate.HibernateIdentityObjectCredentialBinaryValue"
table="jbid_creden_bin_value">
- <cache usage="read-write"/>
+ <cache usage="transactional"/>
<id name="id"
type="java.lang.Long"
access="field">
Modified: portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/mappings/HibernateIdentityObjectCredentialType.hbm.xml
===================================================================
--- portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/mappings/HibernateIdentityObjectCredentialType.hbm.xml 2010-02-23 09:42:10 UTC (rev 1815)
+++ portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/mappings/HibernateIdentityObjectCredentialType.hbm.xml 2010-02-23 13:18:14 UTC (rev 1816)
@@ -4,7 +4,7 @@
<hibernate-mapping>
<class name="org.picketlink.idm.impl.model.hibernate.HibernateIdentityObjectCredentialType"
table="jbid_io_creden_type">
- <cache usage="read-write"/>
+ <cache usage="transactional"/>
<id name="id"
type="java.lang.Long"
Modified: portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/mappings/HibernateIdentityObjectRelationship.hbm.xml
===================================================================
--- portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/mappings/HibernateIdentityObjectRelationship.hbm.xml 2010-02-23 09:42:10 UTC (rev 1815)
+++ portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/mappings/HibernateIdentityObjectRelationship.hbm.xml 2010-02-23 13:18:14 UTC (rev 1816)
@@ -4,7 +4,7 @@
<hibernate-mapping>
<class name="org.picketlink.idm.impl.model.hibernate.HibernateIdentityObjectRelationship"
table="jbid_io_rel">
- <cache usage="read-write"/>
+ <cache usage="transactional"/>
<id name="id"
type="java.lang.Long"
access="field">
@@ -51,7 +51,7 @@
cascade="all, delete-orphan"
fetch="subselect"
lazy="extra">
- <cache usage="read-write"/>
+ <cache usage="transactional"/>
<key column="PROP_ID"/>
<map-key type="string"
column="PROP_NAME"/>
Modified: portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/mappings/HibernateIdentityObjectRelationshipName.hbm.xml
===================================================================
--- portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/mappings/HibernateIdentityObjectRelationshipName.hbm.xml 2010-02-23 09:42:10 UTC (rev 1815)
+++ portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/mappings/HibernateIdentityObjectRelationshipName.hbm.xml 2010-02-23 13:18:14 UTC (rev 1816)
@@ -4,7 +4,7 @@
<hibernate-mapping>
<class name="org.picketlink.idm.impl.model.hibernate.HibernateIdentityObjectRelationshipName"
table="jbid_io_rel_name">
- <cache usage="read-write"/>
+ <cache usage="transactional"/>
<id name="id"
type="java.lang.Long"
@@ -25,7 +25,7 @@
cascade="all, delete-orphan"
lazy="extra"
fetch="subselect">
- <cache usage="read-write"/>
+ <cache usage="transactional"/>
<key column="PROP_ID"/>
<map-key type="string"
column="PROP_NAME"/>
Modified: portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/mappings/HibernateIdentityObjectRelationshipType.hbm.xml
===================================================================
--- portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/mappings/HibernateIdentityObjectRelationshipType.hbm.xml 2010-02-23 09:42:10 UTC (rev 1815)
+++ portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/mappings/HibernateIdentityObjectRelationshipType.hbm.xml 2010-02-23 13:18:14 UTC (rev 1816)
@@ -4,7 +4,7 @@
<hibernate-mapping>
<class name="org.picketlink.idm.impl.model.hibernate.HibernateIdentityObjectRelationshipType"
table="jbid_io_rel_type">
- <cache usage="read-write"/>
+ <cache usage="transactional"/>
<id name="id"
type="java.lang.Long"
access="field">
Modified: portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/mappings/HibernateIdentityObjectType.hbm.xml
===================================================================
--- portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/mappings/HibernateIdentityObjectType.hbm.xml 2010-02-23 09:42:10 UTC (rev 1815)
+++ portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/mappings/HibernateIdentityObjectType.hbm.xml 2010-02-23 13:18:14 UTC (rev 1816)
@@ -4,7 +4,7 @@
<hibernate-mapping>
<class name="org.picketlink.idm.impl.model.hibernate.HibernateIdentityObjectType"
table="jbid_io_type">
- <cache usage="read-write"/>
+ <cache usage="transactional"/>
<id name="id"
type="java.lang.Long"
access="field">
Modified: portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/mappings/HibernateRealm.hbm.xml
===================================================================
--- portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/mappings/HibernateRealm.hbm.xml 2010-02-23 09:42:10 UTC (rev 1815)
+++ portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/mappings/HibernateRealm.hbm.xml 2010-02-23 13:18:14 UTC (rev 1816)
@@ -4,7 +4,7 @@
<hibernate-mapping>
<class name="org.picketlink.idm.impl.model.hibernate.HibernateRealm"
table="jbid_realm">
- <cache usage="read-write"/>
+ <cache usage="transactional"/>
<id name="id"
type="java.lang.Long"
access="field">
@@ -24,7 +24,7 @@
cascade="all, delete-orphan"
fetch="subselect"
lazy="extra">
- <cache usage="read-write"/>
+ <cache usage="transactional"/>
<key column="PROP_ID"/>
<map-key type="string"
column="PROP_NAME"/>
Modified: portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/sybase-mappings/HibernateIdentityObject.hbm.xml
===================================================================
--- portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/sybase-mappings/HibernateIdentityObject.hbm.xml 2010-02-23 09:42:10 UTC (rev 1815)
+++ portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/sybase-mappings/HibernateIdentityObject.hbm.xml 2010-02-23 13:18:14 UTC (rev 1816)
@@ -4,7 +4,7 @@
<hibernate-mapping>
<class name="org.picketlink.idm.impl.model.hibernate.HibernateIdentityObject"
table="jbid_io">
- <cache usage="read-write"/>
+ <cache usage="transactional"/>
<id name="id"
type="java.lang.Long"
access="field">
@@ -16,7 +16,7 @@
cascade="all, delete-orphan"
lazy="extra"
fetch="subselect">
- <cache usage="read-write"/>
+ <cache usage="transactional"/>
<key>
<column name="IDENTITY_OBJECT_ID" />
</key>
@@ -27,7 +27,7 @@
cascade="all, delete-orphan"
lazy="extra"
fetch="subselect">
- <cache usage="read-write"/>
+ <cache usage="transactional"/>
<key>
<column name="IDENTITY_OBJECT_ID" />
</key>
@@ -37,7 +37,7 @@
inverse="true"
lazy="extra"
fetch="subselect">
- <cache usage="read-write"/>
+ <cache usage="transactional"/>
<key>
<column name="FROM_IDENTITY" />
</key>
@@ -65,7 +65,7 @@
cascade="all, delete-orphan"
lazy="extra"
fetch="subselect">
- <cache usage="read-write"/>
+ <cache usage="transactional"/>
<key column="PROP_ID"/>
<map-key type="string"
column="PROP_NAME"/>
@@ -85,7 +85,7 @@
inverse="true"
lazy="extra"
fetch="subselect">
- <cache usage="read-write"/>
+ <cache usage="transactional"/>
<key>
<column name="TO_IDENTITY" />
</key>
Modified: portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/sybase-mappings/HibernateIdentityObjectAttribute.hbm.xml
===================================================================
--- portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/sybase-mappings/HibernateIdentityObjectAttribute.hbm.xml 2010-02-23 09:42:10 UTC (rev 1815)
+++ portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/sybase-mappings/HibernateIdentityObjectAttribute.hbm.xml 2010-02-23 13:18:14 UTC (rev 1816)
@@ -4,7 +4,7 @@
<hibernate-mapping>
<class name="org.picketlink.idm.impl.model.hibernate.HibernateIdentityObjectAttribute"
table="jbid_io_attr">
- <cache usage="read-write"/>
+ <cache usage="transactional"/>
<id name="id"
type="java.lang.Long"
access="field">
@@ -37,7 +37,7 @@
access="field"
lazy="extra"
fetch="subselect">
- <cache usage="read-write"/>
+ <cache usage="transactional"/>
<key column="TEXT_ATTR_VALUE_ID"/>
<element type="string"
column="ATTR_VALUE"/>
Modified: portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/sybase-mappings/HibernateIdentityObjectAttributeBinaryValue.hbm.xml
===================================================================
--- portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/sybase-mappings/HibernateIdentityObjectAttributeBinaryValue.hbm.xml 2010-02-23 09:42:10 UTC (rev 1815)
+++ portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/sybase-mappings/HibernateIdentityObjectAttributeBinaryValue.hbm.xml 2010-02-23 13:18:14 UTC (rev 1816)
@@ -4,7 +4,7 @@
<hibernate-mapping>
<class name="org.picketlink.idm.impl.model.hibernate.HibernateIdentityObjectAttributeBinaryValue"
table="jbid_attr_bin_value">
- <cache usage="read-write"/>
+ <cache usage="transactional"/>
<id name="id"
type="java.lang.Long"
access="field">
Modified: portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/sybase-mappings/HibernateIdentityObjectCredential.hbm.xml
===================================================================
--- portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/sybase-mappings/HibernateIdentityObjectCredential.hbm.xml 2010-02-23 09:42:10 UTC (rev 1815)
+++ portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/sybase-mappings/HibernateIdentityObjectCredential.hbm.xml 2010-02-23 13:18:14 UTC (rev 1816)
@@ -4,7 +4,7 @@
<hibernate-mapping>
<class name="org.picketlink.idm.impl.model.hibernate.HibernateIdentityObjectCredential"
table="jbid_io_creden">
- <cache usage="read-write"/>
+ <cache usage="transactional"/>
<id name="id"
type="java.lang.Long"
@@ -35,7 +35,7 @@
cascade="all, delete-orphan"
lazy="extra"
fetch="subselect">
- <cache usage="read-write"/>
+ <cache usage="transactional"/>
<key column="PROP_ID"/>
<map-key type="string"
column="PROP_NAME"/>
Modified: portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/sybase-mappings/HibernateIdentityObjectCredentialBinaryValue.hbm.xml
===================================================================
--- portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/sybase-mappings/HibernateIdentityObjectCredentialBinaryValue.hbm.xml 2010-02-23 09:42:10 UTC (rev 1815)
+++ portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/sybase-mappings/HibernateIdentityObjectCredentialBinaryValue.hbm.xml 2010-02-23 13:18:14 UTC (rev 1816)
@@ -4,7 +4,7 @@
<hibernate-mapping>
<class name="org.picketlink.idm.impl.model.hibernate.HibernateIdentityObjectCredentialBinaryValue"
table="jbid_creden_bin_value">
- <cache usage="read-write"/>
+ <cache usage="transactional"/>
<id name="id"
type="java.lang.Long"
access="field">
Modified: portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/sybase-mappings/HibernateIdentityObjectCredentialType.hbm.xml
===================================================================
--- portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/sybase-mappings/HibernateIdentityObjectCredentialType.hbm.xml 2010-02-23 09:42:10 UTC (rev 1815)
+++ portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/sybase-mappings/HibernateIdentityObjectCredentialType.hbm.xml 2010-02-23 13:18:14 UTC (rev 1816)
@@ -4,7 +4,7 @@
<hibernate-mapping>
<class name="org.picketlink.idm.impl.model.hibernate.HibernateIdentityObjectCredentialType"
table="jbid_io_creden_type">
- <cache usage="read-write"/>
+ <cache usage="transactional"/>
<id name="id"
type="java.lang.Long"
Modified: portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/sybase-mappings/HibernateIdentityObjectRelationship.hbm.xml
===================================================================
--- portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/sybase-mappings/HibernateIdentityObjectRelationship.hbm.xml 2010-02-23 09:42:10 UTC (rev 1815)
+++ portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/sybase-mappings/HibernateIdentityObjectRelationship.hbm.xml 2010-02-23 13:18:14 UTC (rev 1816)
@@ -4,7 +4,7 @@
<hibernate-mapping>
<class name="org.picketlink.idm.impl.model.hibernate.HibernateIdentityObjectRelationship"
table="jbid_io_rel">
- <cache usage="read-write"/>
+ <cache usage="transactional"/>
<id name="id"
type="java.lang.Long"
access="field">
@@ -51,7 +51,7 @@
cascade="all, delete-orphan"
fetch="subselect"
lazy="extra">
- <cache usage="read-write"/>
+ <cache usage="transactional"/>
<key column="PROP_ID"/>
<map-key type="string"
column="PROP_NAME"/>
Modified: portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/sybase-mappings/HibernateIdentityObjectRelationshipName.hbm.xml
===================================================================
--- portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/sybase-mappings/HibernateIdentityObjectRelationshipName.hbm.xml 2010-02-23 09:42:10 UTC (rev 1815)
+++ portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/sybase-mappings/HibernateIdentityObjectRelationshipName.hbm.xml 2010-02-23 13:18:14 UTC (rev 1816)
@@ -4,7 +4,7 @@
<hibernate-mapping>
<class name="org.picketlink.idm.impl.model.hibernate.HibernateIdentityObjectRelationshipName"
table="jbid_io_rel_name">
- <cache usage="read-write"/>
+ <cache usage="transactional"/>
<id name="id"
type="java.lang.Long"
@@ -25,7 +25,7 @@
cascade="all, delete-orphan"
lazy="extra"
fetch="subselect">
- <cache usage="read-write"/>
+ <cache usage="transactional"/>
<key column="PROP_ID"/>
<map-key type="string"
column="PROP_NAME"/>
Modified: portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/sybase-mappings/HibernateIdentityObjectRelationshipType.hbm.xml
===================================================================
--- portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/sybase-mappings/HibernateIdentityObjectRelationshipType.hbm.xml 2010-02-23 09:42:10 UTC (rev 1815)
+++ portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/sybase-mappings/HibernateIdentityObjectRelationshipType.hbm.xml 2010-02-23 13:18:14 UTC (rev 1816)
@@ -4,7 +4,7 @@
<hibernate-mapping>
<class name="org.picketlink.idm.impl.model.hibernate.HibernateIdentityObjectRelationshipType"
table="jbid_io_rel_type">
- <cache usage="read-write"/>
+ <cache usage="transactional"/>
<id name="id"
type="java.lang.Long"
access="field">
Modified: portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/sybase-mappings/HibernateIdentityObjectType.hbm.xml
===================================================================
--- portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/sybase-mappings/HibernateIdentityObjectType.hbm.xml 2010-02-23 09:42:10 UTC (rev 1815)
+++ portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/sybase-mappings/HibernateIdentityObjectType.hbm.xml 2010-02-23 13:18:14 UTC (rev 1816)
@@ -4,7 +4,7 @@
<hibernate-mapping>
<class name="org.picketlink.idm.impl.model.hibernate.HibernateIdentityObjectType"
table="jbid_io_type">
- <cache usage="read-write"/>
+ <cache usage="transactional"/>
<id name="id"
type="java.lang.Long"
access="field">
Modified: portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/sybase-mappings/HibernateRealm.hbm.xml
===================================================================
--- portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/sybase-mappings/HibernateRealm.hbm.xml 2010-02-23 09:42:10 UTC (rev 1815)
+++ portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/classes/picketlink-idm/sybase-mappings/HibernateRealm.hbm.xml 2010-02-23 13:18:14 UTC (rev 1816)
@@ -4,7 +4,7 @@
<hibernate-mapping>
<class name="org.picketlink.idm.impl.model.hibernate.HibernateRealm"
table="jbid_realm">
- <cache usage="read-write"/>
+ <cache usage="transactional"/>
<id name="id"
type="java.lang.Long"
access="field">
@@ -24,7 +24,7 @@
cascade="all, delete-orphan"
fetch="subselect"
lazy="extra">
- <cache usage="read-write"/>
+ <cache usage="transactional"/>
<key column="PROP_ID"/>
<map-key type="string"
column="PROP_NAME"/>
Modified: portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/conf/jcr/jcr-configuration.xml
===================================================================
--- portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/conf/jcr/jcr-configuration.xml 2010-02-23 09:42:10 UTC (rev 1815)
+++ portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/conf/jcr/jcr-configuration.xml 2010-02-23 13:18:14 UTC (rev 1816)
@@ -126,6 +126,7 @@
</component-plugin>
</external-component-plugins>
+<!--
<external-component-plugins>
<target-component>org.exoplatform.services.naming.InitialContextInitializer</target-component>
<component-plugin>
@@ -156,5 +157,5 @@
</init-params>
</component-plugin>
</external-component-plugins>
-
+-->
</configuration>
Modified: portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/conf/organization/idm-configuration.xml
===================================================================
--- portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/conf/organization/idm-configuration.xml 2010-02-23 09:42:10 UTC (rev 1815)
+++ portal/branches/EPP_5_0_0_ER03_Branch/web/portal/src/main/webapp/WEB-INF/conf/organization/idm-configuration.xml 2010-02-23 13:18:14 UTC (rev 1816)
@@ -37,9 +37,12 @@
<property name="hibernate.current_session_context_class" value="thread"/>
<property name="hibernate.cache.use_second_level_cache" value="true"/>
<property name="hibernate.cache.use_query_cache" value="true"/>
- <!--CHANGEME HashtableCacheProvider shold not be used in production env-->
- <property name="hibernate.cache.provider_class" value="org.hibernate.cache.HashtableCacheProvider"/>
- <property name="hibernate.cglib.use_reflection_optimizer" value="true"/>
+
+ <property name="hibernate.cache.region.factory_class" value="org.hibernate.cache.jbc2.MultiplexedJBossCacheRegionFactory" />
+ <property name="hibernate.cache.region.jbc2.query.localonly" value="true" />
+ <property name="hibernate.transaction.manager_lookup_class" value="org.hibernate.transaction.JBossTransactionManagerLookup" />
+
+ <property name="hibernate.bytecode.use_reflection_optimizer" value="true"/>
<property name="hibernate.connection.datasource" value="${gatein.idm.datasource.name}${container.name.suffix}"/>
<property name="hibernate.connection.autocommit" value="true"/>
<!--
@@ -178,6 +181,7 @@
</init-params>
</component>
+<!--
<external-component-plugins>
<target-component>org.exoplatform.services.naming.InitialContextInitializer</target-component>
<component-plugin>
@@ -208,6 +212,7 @@
</init-params>
</component-plugin>
</external-component-plugins>
+-->
<external-component-plugins>
<target-component>org.exoplatform.services.database.HibernateService</target-component>
14 years, 10 months
gatein SVN: r1815 - portal/trunk/component/identity/src/main/java/org/exoplatform/services/organization/idm.
by do-not-reply@jboss.org
Author: bdaw
Date: 2010-02-23 04:42:10 -0500 (Tue, 23 Feb 2010)
New Revision: 1815
Modified:
portal/trunk/component/identity/src/main/java/org/exoplatform/services/organization/idm/MembershipDAOImpl.java
Log:
- GTNPORTAL-617 - memberships management issue
Modified: portal/trunk/component/identity/src/main/java/org/exoplatform/services/organization/idm/MembershipDAOImpl.java
===================================================================
--- portal/trunk/component/identity/src/main/java/org/exoplatform/services/organization/idm/MembershipDAOImpl.java 2010-02-23 09:40:49 UTC (rev 1814)
+++ portal/trunk/component/identity/src/main/java/org/exoplatform/services/organization/idm/MembershipDAOImpl.java 2010-02-23 09:42:10 UTC (rev 1815)
@@ -232,8 +232,21 @@
}
- if (!hasRole)
+ boolean associated = false;
+
+ try
{
+ associated = getIdentitySession().getRelationshipManager().isAssociatedByKeys(groupId, m.getUserName());
+ }
+ catch (Exception e)
+ {
+ //TODO:
+ log.info("Identity operation error: ", e);
+ }
+
+ if (!hasRole &&
+ !(isAssociationMapped() && getAssociationMapping().equals(m.getMembershipType()) && associated))
+ {
return m;
}
@@ -257,19 +270,6 @@
}
}
- boolean associated = false;
-
- try
- {
- associated = getIdentitySession().getRelationshipManager().isAssociatedByKeys(m.getGroupId(), m.getUserName());
- }
- catch (Exception e)
- {
- //TODO:
- log.info("Identity operation error: ", e);
-
- }
-
if (isAssociationMapped() && getAssociationMapping().equals(m.getMembershipType()) && associated)
{
Set<String> keys = new HashSet<String>();
14 years, 10 months
gatein SVN: r1814 - portal/trunk/component/common/src/main/java/conf.
by do-not-reply@jboss.org
Author: thomas.heute(a)jboss.com
Date: 2010-02-23 04:40:49 -0500 (Tue, 23 Feb 2010)
New Revision: 1814
Modified:
portal/trunk/component/common/src/main/java/conf/configuration.xml
Log:
GTNPORTAL-693: Windows: SEVERE: Cannot load property file
Should be validated by someone using Tomcat on Windows
Modified: portal/trunk/component/common/src/main/java/conf/configuration.xml
===================================================================
--- portal/trunk/component/common/src/main/java/conf/configuration.xml 2010-02-23 09:11:54 UTC (rev 1813)
+++ portal/trunk/component/common/src/main/java/conf/configuration.xml 2010-02-23 09:40:49 UTC (rev 1814)
@@ -31,7 +31,7 @@
<init-params>
<value-param profiles="tomcat">
<name>properties.url</name>
- <value>file://${catalina.base}/gatein/conf/configuration.properties</value>
+ <value>file:///${catalina.base}/gatein/conf/configuration.properties</value>
</value-param>
<value-param profiles="jboss">
<name>properties.url</name>
14 years, 10 months
--- portal/trunk/component/wsrp/src/main/java/org/gatein/portal/wsrp/ExoKernelIntegration.java 2010-02-23 15:06:34 UTC (rev 1821)
+++ portal/trunk/component/wsrp/src/main/java/org/gatein/portal/wsrp/ExoKernelIntegration.java 2010-02-23 15:42:06 UTC (rev 1822)
@@ -27,6 +27,7 @@
import org.exoplatform.container.ExoContainerContext;
import org.exoplatform.container.configuration.ConfigurationManager;
import org.exoplatform.container.xml.InitParams;
+import org.exoplatform.services.jcr.ext.hierarchy.NodeHierarchyCreator;
import org.gatein.common.logging.Logger;
import org.gatein.common.logging.LoggerFactory;
import org.gatein.pc.api.PortletInvoker;
@@ -87,9 +88,9 @@
private static final String WSRP_ADMIN_GUI_CONTEXT_PATH = "/wsrp-admin-gui";
public ExoKernelIntegration(ExoContainerContext context, InitParams params, ConfigurationManager configurationManager,
- org.exoplatform.portal.pc.ExoKernelIntegration pc) throws Exception
+ org.exoplatform.portal.pc.ExoKernelIntegration pc, NodeHierarchyCreator nhc) throws Exception
{
// IMPORTANT: even though PC ExoKernelIntegration is not used anywhere in the code, it's still needed for pico
// to properly make sure that this service is started after the PC one. Yes, Pico is crap. :/
// todo: we currently only allow the service to go through initialization if we are running in the default portal
14 years, 10 months
@@ -87,9 +88,9 @@
{
- // IMPORTANT: even though PC ExoKernelIntegration is not used anywhere in the code, it's still needed for pico
+ // IMPORTANT: even though PC ExoKernelIntegration and NodeHierarchyCreator is not used anywhere in the code, it's still needed for pico
// to properly make sure that this service is started after the PC one. Yes, Pico is crap. :/
// todo: we currently only allow the service to go through initialization if we are running in the default portal
gatein SVN: r1820 - in portal/trunk: examples/extension/war/src/main/webapp/WEB-INF and 1 other directories.
by do-not-reply@jboss.org
Author: julien_viet
Date: 2010-02-23 09:50:43 -0500 (Tue, 23 Feb 2010)
New Revision: 1820
Added:
portal/trunk/component/portal/src/main/java/gatein_resources_1_0.xsd
Removed:
portal/trunk/web/portal/src/main/webapp/WEB-INF/gatein_resources_1_0.xsd
Modified:
portal/trunk/examples/extension/war/src/main/webapp/WEB-INF/gatein-resources.xml
Log:
GTNPORTAL-722 : fix incorrect gatein-resources.xsd
GTNPORTAL-501 : gatein_resources_1_0.xsd has incorrect target namespace
Copied: portal/trunk/component/portal/src/main/java/gatein_resources_1_0.xsd (from rev 1808, portal/trunk/web/portal/src/main/webapp/WEB-INF/gatein_resources_1_0.xsd)
===================================================================